#
# spec file for package kf6-kconfig
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define qt6_version 6.7.0

%define rname kconfig
# Full KF6 version (e.g. 6.11.0)
%{!?_kf6_version: %global _kf6_version %{version}}
# Last major and minor KF6 version (e.g. 6.0)
%{!?_kf6_bugfix_version: %define _kf6_bugfix_version %(echo %{_kf6_version} | awk -F. '{print $1"."$2}')}
%bcond_without released
Name:           kf6-kconfig
Version:        6.11.0
Release:        1.2
Summary:        Advanced configuration system
License:        LGPL-2.1-or-later AND GPL-2.0-or-later
URL:            https://www.kde.org
Source:         %{rname}-%{version}.tar.xz
%if %{with released}
Source1:        %{rname}-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
Source99:       kf6-kconfig-rpmlintrc
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  kf6-extra-cmake-modules >= %{_kf6_bugfix_version}
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}
BuildRequires:  cmake(Qt6DBus) >= %{qt6_version}
BuildRequires:  cmake(Qt6Gui) >= %{qt6_version}
BuildRequires:  cmake(Qt6LinguistTools) >= %{qt6_version}
BuildRequires:  cmake(Qt6Qml) >= %{qt6_version}
BuildRequires:  cmake(Qt6Quick) >= %{qt6_version}
BuildRequires:  cmake(Qt6ToolsTools) >= %{qt6_version}
BuildRequires:  cmake(Qt6Xml) >= %{qt6_version}

%description
KConfig provides an advanced configuration system. It is made of three parts:
KConfigCore, KConfigGui and KConfigQml.

KConfigCore provides access to the configuration files themselves. It features:

- centralized definition: define your configuration in an XML file and use
`kconfig_compiler` to generate classes to read and write configuration entries.

- lock-down (kiosk) support.

KConfigGui provides a way to hook widgets to the configuration so that they are
automatically initialized from the configuration and automatically propagate
their changes to their respective configuration files.

KConfigQml provides QtQuick bindings to KConfig, allowing it to be used with QML.

%package imports
Summary:        QML imports for kconfig
Supplements:    (libKF6ConfigCore6 and libQt6Qml6)

%description imports
QML imports for kconfig.

%package -n libKF6ConfigCore6
Summary:        System for configuration files
Requires:       kf6-kconfig >= %{version}
Recommends:     kconf_update6 = %{version}

%description -n libKF6ConfigCore6
KConfig provides an advanced configuration system. It is made of two parts:
KConfigCore and KConfigGui.

KConfigCore provides access to the configuration files themselves.

%package -n libKF6ConfigGui6
Summary:        Widgets hooks for configuration entities
Requires:       libKF6ConfigCore6 = %{version}

%description -n libKF6ConfigGui6
KConfigGui provides a way to hook widgets to the configuration so that they are
automatically initialized from the configuration and automatically propagate
their changes to their respective configuration files.

%package -n libKF6ConfigQml6
Summary:        QtQuick bindings for configuration entities
Requires:       libKF6ConfigCore6 = %{version}
Requires:       libKF6ConfigGui6 = %{version}

%description -n libKF6ConfigQml6
KConfigQml provides QtQuick bindings to KConfig, which allows using the library with
QML.

%package -n kconf_update6
Summary:        Configuration file access
Requires:       libKF6ConfigCore6 = %{version}

%description -n kconf_update6
KConfig provides an advanced configuration system. It is made of two parts:
KConfigCore and KConfigGui.

This package contains the kconf_update tool.

%package devel
Summary:        KConfig Development files
Requires:       kconf_update6 = %{version}
Requires:       libKF6ConfigCore6 = %{version}
Requires:       libKF6ConfigGui6 = %{version}
Requires:       libKF6ConfigQml6 = %{version}
Requires:       cmake(Qt6DBus) >= %{qt6_version}
Requires:       cmake(Qt6Qml) >= %{qt6_version}
Requires:       cmake(Qt6Xml) >= %{qt6_version}

%description devel
KConfig provides an advanced configuration system. It is made of two parts:
KConfigCore and KConfigGui.

KConfigCore provides access to the configuration files themselves. It features:

- centralized definition: define your configuration in an XML file and use
`kconfig_compiler` to generate classes to read and write configuration entries.

- lock-down (kiosk) support.

KConfigGui provides a way to hook widgets to the configuration so that they are
automatically initialized from the configuration and automatically propagate
their changes to their respective configuration files. Development files.

%lang_package -n libKF6ConfigCore6

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
%cmake_kf6 -DBUILD_QCH:BOOL=TRUE

%kf6_build

%install
%kf6_install

%fdupes %{buildroot}

%find_lang kconfig6 --with-qt --without-mo

%ldconfig_scriptlets -n libKF6ConfigCore6
%ldconfig_scriptlets -n libKF6ConfigGui6
%ldconfig_scriptlets -n libKF6ConfigQml6

%files
%{_kf6_bindir}/kreadconfig6
%{_kf6_bindir}/kwriteconfig6
%{_kf6_debugdir}/kconfig.categories
%{_kf6_debugdir}/kconfig.renamecategories

%files imports
%{_kf6_qmldir}/org/kde/config/

%files -n libKF6ConfigCore6
%license LICENSES/*
%doc README.md
%{_kf6_libdir}/libKF6ConfigCore.so.*

%files -n libKF6ConfigGui6
%{_kf6_libdir}/libKF6ConfigGui.so.*

%files -n libKF6ConfigQml6
%{_kf6_libdir}/libKF6ConfigQml.so.*

%files -n kconf_update6
%{_kf6_libexecdir}/kconf_update

%files devel
%doc %{_kf6_qchdir}/KF6Config.*
%{_kf6_includedir}/KConfig/
%{_kf6_includedir}/KConfigCore/
%{_kf6_includedir}/KConfigGui/
%{_kf6_includedir}/KConfigQml/
%{_kf6_cmakedir}/KF6Config/
%{_kf6_libdir}/libKF6ConfigCore.so
%{_kf6_libdir}/libKF6ConfigGui.so
%{_kf6_libdir}/libKF6ConfigQml.so
%{_kf6_libexecdir}/kconfig_compiler_kf6

%files -n libKF6ConfigCore6-lang -f kconfig6.lang

%changelog
* Sat Feb  8 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.11.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.11.0
- Changes since 6.10.0:
  * Update dependency version to 6.11.0
  * Enforce QtNext tests to pass again
  * Move global cache out of function again
  * kwriteconfig: Add a flag to notify
  * Make global parse cache local to parseGlobalFiles()
  * Add xml/yaml linting
  * Make kcfg testfiles valid wrt kcfg.xsd
  * Use unique pointer for lock file
  * Simplify KConfigIniBackend
  * Enable QStandardPaths testMode for more tests
  * Add a way to register QML types as uncreatable
  * Don't ignore the result of QFile::open
  * CI: Add linux-qt6-next build
  * Enable QStandardPaths test mode for TestStateConfig
  * [kconfig_compiler] Fix code generation for state config without name arg
  * Fix moving values between nested groups
  * Read defaults from Windows registry
  * Update version to 6.11.0
* Tue Jan  7 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.10.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.10.0
- Changes since 6.9.0:
  * Update dependency version to 6.10.0
  * Fix shortcuts for mac os
  * Replace BufferFragment by QByteArrayView
  * docs(DESIGN): Fix URL to tutorial
  * Update version to 6.10.0
* Sun Dec  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.9.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.9.0
- Changes since 6.8.0:
  * Update dependency version to 6.9.0
  * Add QML_REGISTRATION option to the config macro documentation
  * KWindowStateSaver: Increase the rate limit on the slow part of config saving
  * It compiles fine without deprecated methods
  * Now we depend against qt6.6.0
  * Fix restoration of maximization state for QtQuick windows (for real) (kde#494359)
  * Update version to 6.9.0
* Mon Nov  4 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.8.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.8.0
- Changes since 6.7.0:
  * Update dependency version to 6.8.0
  * kwindowconfig: If sizes are same as default, revert them to default when saving
  * Update version to 6.8.0
  * Add CI for static builds on Linux
  * Correctly install QML module in a static build
* Mon Oct  7 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.7.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.7.0
- Changes since 6.6.0:
  * Update dependency version to 6.7.0
  * Make unit tests work with a static Qt build
  * Update version to 6.7.0
* Sat Sep  7 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.6.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.6.0
- Changes since 6.5.0:
  * KStandardAction: Use windowIcon for AboutApp icon again
  * Fix macro documentation
  * ci: add Alpine/musl job
  * Fix warning from staterc migration when there's no "old" file to migrate
  * Update KF6 TODO comments to KF7 given that they weren't addressed in KF6
  * Update version to 6.6.0
* Mon Aug  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.5.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.5.0
- Changes since 6.4.0:
  * Update dependency version to 6.5.0
  * ksharedconfig: move statercs to state dir
  * Explain what "desktop entry spec separator semantics" means
  * Reapply "don't create root-only readable files in /etc/xdg"
  * Make Qt6Quick dependency for QML plugin private
  * Update version to 6.5.0
  * Expose KWindowStateSaver in the QML interface
  * Sync config group on KWindowStateSaver::timerEvent
  * don't do tests in ~/.kde-unit-test
* Tue Jul  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.4.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.4.0
- Changes since 6.3.0:
  * Fix two cmakelint types of issue
  * Fix KCONFIG_USE_QML=OFF by moving ECMQmlModule behind the conditional
  * kconfig_compiler: Don't generate .moc include
  * kconfig_compiler: Allow generating QML type registration macros
  * kconfig_compiler: Use automoc for GENERATE_MOC
  * Avoid unused variable definition
  * Allow desktop files to be a symbolic link
  * Fix compile
  * KStandardActions: Use C++11 for loop
  * fix compile dependencies for windows
  * Register KCoreConfigSkeleton to QML
  * provide a generic named USE_DBUS option to allow to choose if to use it
  * don't warn if no dbus enabled
* Wed Jun  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.3.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.3.0/
- Changes since 6.2.0:
  * ensure test works with Qt 6.7 on Windows
  * Use QT_TRANSLATE_NOOP instead of QT_TR_NOOP for KStandardActions
  * Add helper method to fully move a group to another
  * Deprecate ctor that takes a backend
  * Move parts of KStandardAction to KConfigGui
  * Remove KConfigBackend abstraction
  * Add a mutex to protect globalData
  * kconfigxt: Remove docs for SourceExtension parameter which was removed in KF6
  * Remove explicit maintainer from metainfo
  * Use ellipsis character instead of three dots in UI strings
* Mon May  6 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.2.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/6.2.0/
- Changes since 6.1.0:
  * avoid allocations while parsing int/float lists
  * Adapt kdesktopfiletest to QTemporaryFile behavior change
  * Guard header with an ifndef and include moc generates sources in the cpp file
  * autotests: Don't use a timeout in testLocalDeletion
  * Adjust kconfig_compiler autotests to include a version without kcfgc
  * Add a CMake function to add a kcfg file without kcfgc
  * gitignore: add VS Code dir
* Fri Apr  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.1.0
  * New feature release
- Changes since 6.0.0:
  * update version for new release
  * Don't search for QtDBus on Windows/macOS/Android
  * Register KConfigPropertyMap to QML
  * kconf_update: Also run .upd files if times match but done is empty (kde#483795)
  * Add unittest that URL[$e] works, for bug 482889
- Drop patch, merged upstream:
  * 0001-kconf_update-Also-run-.upd-files-if-times-match-but-.patch
* Sat Mar 16 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to fix missing config migration (kde#483795):
  * 0001-kconf_update-Also-run-.upd-files-if-times-match-but-.patch
* Wed Feb 21 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.0
  * New bugfix release
  * Release announcement not available yet
- Changes since 5.249.0:
  * update version for new release
  * KConfigLoader: reduce string allocations when parsing config items
  * KConfigLoader: use QString::trimmed rvalue overload
  * kdesktopfile: don't return const value
  * kdesktopfileaction: rule of five - add move operations
  * kdesktopfileaction: use =default for trivial default operations
  * kdesktopfileaction: don't needlessly copy strings
  * update version for new release
* Wed Jan 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.249.0 (6.0 RC 2):
  * New bugfix release
  * For more details see https://kde.org/announcements/megarelease/6/rc2/
* Mon Jan 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.248.0 (6.0 RC 1)
  * For more details please see:
    https://kde.org/announcements/megarelease/6/rc1/
* Sat May 27 2023 Christophe Marin <christophe@krop.fr>
- Init kf6-kconfig
